<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>애플리케이션 선택</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>설치된 애플리케이션</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>사용자 정의 명령</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>실행할 명령줄:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>애플리케이션 이름:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;다음과 같은 특수문자가 명령줄에 사용될 수 있습니다.:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;：한 개의 파일 이름 표시&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;：여러 파일 이름 표시&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;：한 개의 파일 URI 표시&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;：여러 URI 표시&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>명령이 실행된 후에도 창을 열어두기</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>터미널 에뮬레이터에서 실행</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>선택된 애플리케이션을 이 파일 형식의 기본 애플리케이션으로 설정</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>북마크 편집</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>항목 추가(&amp;A)</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>항목 삭제(&amp;R)</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>항목을 재정렬 하기 위해 드래그 앤 드롭 사용</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>실행 파일</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>열기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>실행(&amp;X)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>터미널에서 실행(&amp;T)</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>경로:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>파일 이름:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>파일 형식:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translatorcomment>적절한 용어로 번역이 필요</translatorcomment>
        <translation type="unfinished">대상 위치:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>진행중:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>준비중...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>진행</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>남은 시간:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>처리된 파일:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>파일 속성</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>파일 형식:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>MIME 형식:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>파일 크기:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>디스크 할당 크기:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>수정한 날짜:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translatorcomment>의역하였습니다.</translatorcomment>
        <translation>원본 경로:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translatorcomment>의역하였습니다.</translatorcomment>
        <translation>연결 프로그램:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>액세스한 날짜:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>내용:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="371"/>
        <source>Device Usage:</source>
        <translation>장치 사용량:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="381"/>
        <source>Permissions</source>
        <translation>권한</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="396"/>
        <source>Ownership</source>
        <translation>소유권</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="420"/>
        <location filename="../file-props.ui" line="485"/>
        <location filename="../file-props.ui" line="599"/>
        <source>Group:</source>
        <translation>그룹:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="433"/>
        <location filename="../file-props.ui" line="468"/>
        <location filename="../file-props.ui" line="547"/>
        <source>Owner:</source>
        <translation>소유자:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="449"/>
        <source>Access Control</source>
        <translatorcomment>의역하였습니다.</translatorcomment>
        <translation>접근 권한</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="502"/>
        <location filename="../file-props.ui" line="651"/>
        <source>Other:</source>
        <translation>기타:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="519"/>
        <source>Make the file executable</source>
        <translation>실행 가능하도록 설정</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="560"/>
        <location filename="../file-props.ui" line="612"/>
        <location filename="../file-props.ui" line="664"/>
        <source>Read</source>
        <translation>읽기</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="573"/>
        <location filename="../file-props.ui" line="625"/>
        <location filename="../file-props.ui" line="677"/>
        <source>Write</source>
        <translation>쓰기</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="586"/>
        <location filename="../file-props.ui" line="638"/>
        <location filename="../file-props.ui" line="690"/>
        <source>Execute</source>
        <translation>실행</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="699"/>
        <source>Sticky</source>
        <translation type="unfinished">스티키</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="706"/>
        <source>SetUID</source>
        <translation type="unfinished">UID 설정</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="713"/>
        <source>SetGID</source>
        <translation type="unfinished">GID 설정</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Advanced Mode</source>
        <translation>고급 설정</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>개별화</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>“%1” 파일의 열 애플리케이션을 선택하세요.</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>폴더</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>빈 파일</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>선택한 디렉토리인 “%1”은 유효하지 않습니다</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>불러오는 중……</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;하위 폴더 없음&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>새 탭에서 열기(&amp;A)</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>새 창에서 열기(&amp;D)</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>터미널에서 열기(&amp;I)</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>여기에 복사</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>여기에 이동</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>여기에 바로 가기 만들기</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>새 북마크</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>이 파일 &apos;%1&apos;은 데스크톱 앤트리입니다.
무엇을 하길 원하십니까?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>이 텍스트 파일 &apos;%1&apos;은 실행가능한 스크립트입니다.
무엇을 하길 원하십니까?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>이 파일 &apos;%1&apos;은 실행가능합니다. 실행하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="109"/>
        <source>Go Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="110"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Go Forward</source>
        <translation>앞으로</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="117"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="124"/>
        <source>Reload</source>
        <translation>새로고침</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="125"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="142"/>
        <source>Create Folder</source>
        <translation>새 폴더</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Icon View</source>
        <translation>아이콘</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Thumbnail View</source>
        <translation>썸네일</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Compact View</source>
        <translation>간단히</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Detailed List View</source>
        <translation>자세히</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Icon Sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Size of big icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="181"/>
        <source>Size of small icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="188"/>
        <source>Size of thumbnails:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="204"/>
        <source>Show Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="209"/>
        <source>Show File Tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="220"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="544"/>
        <location filename="../filedialog.cpp" line="939"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="544"/>
        <source>Please select a file</source>
        <translation>파일을 선택하세요.</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="586"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 는 이미 존재합니다.
덮어쓸까요?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="909"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>경로 “%1&quot;는 존재하지 않습니다.</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="923"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>“%1”는 디렉토리가 아닙니다.</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="929"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>“%1”는 파일이 아닙니다.</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1081"/>
        <location filename="../filedialog.cpp" line="1189"/>
        <source>&amp;Open</source>
        <translation>열기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1084"/>
        <location filename="../filedialog.cpp" line="1197"/>
        <source>&amp;Save</source>
        <translation>저장(&amp;S)</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1091"/>
        <source>All Files (*)</source>
        <translation>모든 파일 (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>파일 저장</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="85"/>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="89"/>
        <source>Open With...</source>
        <translation>연결 프로그램...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Default Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="124"/>
        <source>Many files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="125"/>
        <source>Do you want to open these %1 files?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="138"/>
        <source>Other Applications</source>
        <translation>다른 애플리케이션</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="145"/>
        <source>Create &amp;New</source>
        <translation>새로 만들기(&amp;N)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="164"/>
        <source>&amp;Restore</source>
        <translation>복원(&amp;R)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="174"/>
        <source>Cut</source>
        <translation>잘라내기</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="178"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="182"/>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="186"/>
        <location filename="../filemenu.cpp" line="436"/>
        <source>&amp;Move to Trash</source>
        <translation>휴지통으로 이동(&amp;M)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="190"/>
        <source>Rename</source>
        <translation>이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="247"/>
        <source>Extract to...</source>
        <translation>압축 풀기...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="255"/>
        <source>Extract Here</source>
        <translation>여기에 압축 풀기</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="262"/>
        <source>Compress</source>
        <translation>압축</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="271"/>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="282"/>
        <source>Trust selected executables</source>
        <translation>선택된 실행 파일을 신뢰</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Trust this executable</source>
        <translation>이 실행 파일을 신뢰</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="371"/>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="168"/>
        <location filename="../filemenu.cpp" line="436"/>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translatorcomment>내용 이해를 위해 일부 내용 추가</translatorcomment>
        <translation>일부 파일을 휴지통으로 이동할 수 없습니다. 파일 시스템이 이 작업을 지원하지 않습니다.
휴지통으로 이동하지 않고 완전히 삭제할까요?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected files?</source>
        <translation>선택된 파일을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>선택된 파일을 휴지통으로 이동하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>파일 이동</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>다음 파일을 대상 폴더로 이동 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>파일 복사</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>다음 파일을 대상 폴더로 복사 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>휴지통 파일</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>다음 파일을 휴지통으로 이동 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>파일 삭제</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>다음 파일을 삭제 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>바로가기 만들기</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>다음 파일에 대해 바로가기를 만드는 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>속성 변경</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>다음 파일의 속성을 변경 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>휴지통 파일 복원</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>다음 파일을 휴지통으로 부터 복원 중:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="146"/>
        <location filename="../fileoperationdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>폴더 내용 보기</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>폴더 내용을 보고 변경하기</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>읽기</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>읽기 쓰기</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>권한 없음</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>다른 형식의 파일</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>여러 파일</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="354"/>
        <source>%p% used</source>
        <translation>%p% 사용됨</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="355"/>
        <source>%1 Free of %2</source>
        <translation>%2 중에서 %1 비어 있음</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="400"/>
        <source>no file</source>
        <translation>파일 없음</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="402"/>
        <source>one file</source>
        <translation>한 개의 파일</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="404"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%L개의 파일</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="438"/>
        <source>Select an icon</source>
        <translation>아이콘 선택</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="440"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>이미지（*.png *.xpm *.svg *.svgz）</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Apply changes</source>
        <translation>변경 사항 적용</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="541"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>모든 파일과 하위 폴더에 대해 변경 사항을 적용하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>검색을 위해 최소 한 개 이상의 디렉토리를 추가해야 합니다.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>폴더 선택</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="477"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>자신의 위치로 디렉토리를 복사할 수 없습니다!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="528"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Non-native 파일 시스템으로 링크를 만들 수 없습니다</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="48"/>
        <source>Create &amp;New</source>
        <translation>새로 만들기(&amp;N)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="53"/>
        <source>&amp;Paste</source>
        <translation>붙여넣기(&amp;P)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="59"/>
        <source>Select &amp;All</source>
        <translation>모두 선택(&amp;A)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="63"/>
        <source>Invert Selection</source>
        <translation>선택 역전</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Sorting</source>
        <translation>정렬</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="74"/>
        <source>Show Hidden</source>
        <translation>숨긴 파일 보기</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="107"/>
        <source>Folder Pr&amp;operties</source>
        <translation>폴더 속성(&amp;O)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="150"/>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="172"/>
        <source>By File Name</source>
        <translation>파일 이름 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="173"/>
        <source>By Modification Time</source>
        <translation>수정 시간 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="174"/>
        <source>By Creation Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="177"/>
        <source>By Deletion Time</source>
        <translation>삭제 시간 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="180"/>
        <source>By File Size</source>
        <translation>파일 크기 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="181"/>
        <source>By File Type</source>
        <translation>파일 형식 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="182"/>
        <source>By File Owner</source>
        <translation>파일 소유자 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>By File Group</source>
        <translation>파일 그룹 순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="189"/>
        <source>Ascending</source>
        <translation>오름차순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="194"/>
        <source>Descending</source>
        <translation>내림차순</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="211"/>
        <source>Folder First</source>
        <translation>첫 번째 폴더</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="219"/>
        <source>Hidden Last</source>
        <translation type="unfinished">마지막 숨기기</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Case Sensitive</source>
        <translation>대/소문자 구분</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="304"/>
        <source>Location:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="308"/>
        <source>File type:</source>
        <translation>파일 형식:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="313"/>
        <source>File size:</source>
        <translation>파일 크기:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="317"/>
        <source>Last modified:</source>
        <translation>마지막 수정:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="318"/>
        <source>Last accessed:</source>
        <translation>마지막 액세스:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="326"/>
        <source>Owner:</source>
        <translation>소유자:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="327"/>
        <source>Group:</source>
        <translation>그룹:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="394"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="397"/>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="400"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="403"/>
        <source>Modified</source>
        <translation>수정됨</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="406"/>
        <source>Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="409"/>
        <source>Deleted</source>
        <translation>삭제됨</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="412"/>
        <source>Owner</source>
        <translation>소유자</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="415"/>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="373"/>
        <source>Auto-resize columns</source>
        <translation>자동으로 열 크기 조정</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="390"/>
        <source>Visible Columns</source>
        <translation>열 표시</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>기울임꼴</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>연결(&amp;C)</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>경로 수정(&amp;E)</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>경로 복사(&amp;C)</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>바탕 화면</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>애플리케이션</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>장치</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="137"/>
        <source>Bookmarks</source>
        <translation>북마크</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="228"/>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="481"/>
        <source>Open in New Tab</source>
        <translation>새 탭으로 열기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="484"/>
        <source>Open in New Window</source>
        <translation>새 창으로 열기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="496"/>
        <source>Empty Trash</source>
        <translation>빈 휴지통</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="516"/>
        <location filename="../placesview.cpp" line="573"/>
        <source>Hide</source>
        <translation>숨기기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="533"/>
        <source>Move Bookmark Up</source>
        <translation>북마크 위로 옮기기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="538"/>
        <source>Move Bookmark Down</source>
        <translation>북마크 아래로 옮기기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="542"/>
        <source>Rename Bookmark</source>
        <translation>북마크 이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="545"/>
        <source>Remove Bookmark</source>
        <translation>북마크 삭제</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="554"/>
        <location filename="../placesview.cpp" line="587"/>
        <source>Unmount</source>
        <translation>마운트 해제</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="558"/>
        <source>Mount</source>
        <translation>마운트</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Eject</source>
        <translation>꺼내기</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="599"/>
        <source>Show All Entries</source>
        <translation>모든 항목 보기</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>형식: %1
크기: %2
수정됨: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>형식: %1
수정됨: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>덮어쓰기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>이름 바꾸기(&amp;R)</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>목록</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>디렉토리 트리</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>파일 “%s”를 휴지통에서 복원할 수 없습니다: 원래 위치가 존재하지 않습니다.</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>마운트</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>익명으로 접속(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>사용자로 접속(&amp;S):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>사용자 이름(&amp;U):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>비밀번호(&amp;P):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>도메인(&amp;D):</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translatorcomment>정확한 번역이 맞는지 확신이 없음.</translatorcomment>
        <translation type="unfinished">비밀번호 바로 잊기(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>이 세션에서 비밀번호를 저장(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>영구적으로 비밀번호 저장(&amp;F)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>파일 이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>새 이름 입력:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="104"/>
        <location filename="../filepropsdialog.cpp" line="565"/>
        <location filename="../mountoperation.cpp" line="207"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="283"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>폴더 만들기</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>새 파일</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>새로운 파일 이름 입력하세요:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>새 텍스트 파일</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>새로운 폴더 이름 입력하세요:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>새 폴더</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>새로운 %1에 대해 이름을 입력하세요:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="582"/>
        <source>Custom Icon Error</source>
        <translation>사용자 정의 아이콘 오류</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>이 경로는 마운트되지 않았습니다.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="331"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>유효하지 않은 데스크톱 엔트리 파일입니다: “%1”</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="367"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>&apos;%1&apos;를 실행할 기본 애플리케이션이 설정되어 있지 않습니다</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="408"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation type="unfinished">&apos;%1&apos;로 작업 경로를 설정할 수 없습니다:%2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="123"/>
        <source>Identifier: </source>
        <translation>식별자: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>덮어쓸 파일 확인</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;이 위치에 동일한 이름의 파일이 존재합니다.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;덮어쓰시겠습니까?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>다음 파일을 포함합니까?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>파일 이름(&amp;F):</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>모든 존재하는 파일에 이 설정을 적용</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>파일 검색</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>이름/위치</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>파일 이름 규칙:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>표준 정규식 사용</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>검색할 위치:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>추가(&amp;A)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>삭제(&amp;R)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>숨긴 파일도 검색</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>파일 형식</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>다음 형식의 파일만 검색:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>텍스트 파일</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>이미지 파일</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>오디오 파일</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>비디오 파일</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>폴더</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>내용</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>포함하는 파일:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>표준 정규식 사용(&amp;U)</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>파일 크기:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>최소 크기:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation>바이트</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>최대 크기:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation>하위 디렉토리 검색</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>최종 수정 시간:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>마지막 날짜:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>시작 날짜:</translation>
    </message>
</context>
</TS>
